Class: Ifeelgoods::RedemptionRewardCodes
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Ifeelgoods::RedemptionRewardCodes
- Defined in:
- lib/ifeelgoods/models/redemption_reward_codes.rb
Overview
Only available when redemption is redeemed. Please refer to FAQ for more information about reward_codes object.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#codes ⇒ Object
Returns the value of attribute codes.
-
#expiration_datetime ⇒ Object
The expiration date of the reward code(s), if applicable.
-
#type ⇒ Object
Indicates whether the reward has a single code or multiple codes.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RedemptionRewardCodes
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RedemptionRewardCodes
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/ifeelgoods/models/redemption_reward_codes.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Ifeelgoods::RedemptionRewardCodes` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Ifeelgoods::RedemptionRewardCodes`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'codes') if (value = attributes[:'codes']).is_a?(Array) self.codes = value end end if attributes.key?(:'expiration_datetime') self.expiration_datetime = attributes[:'expiration_datetime'] end end |
Instance Attribute Details
#codes ⇒ Object
Returns the value of attribute codes.
22 23 24 |
# File 'lib/ifeelgoods/models/redemption_reward_codes.rb', line 22 def codes @codes end |
#expiration_datetime ⇒ Object
The expiration date of the reward code(s), if applicable.
25 26 27 |
# File 'lib/ifeelgoods/models/redemption_reward_codes.rb', line 25 def expiration_datetime @expiration_datetime end |
#type ⇒ Object
Indicates whether the reward has a single code or multiple codes.
20 21 22 |
# File 'lib/ifeelgoods/models/redemption_reward_codes.rb', line 20 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
59 60 61 |
# File 'lib/ifeelgoods/models/redemption_reward_codes.rb', line 59 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/ifeelgoods/models/redemption_reward_codes.rb', line 64 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 |
# File 'lib/ifeelgoods/models/redemption_reward_codes.rb', line 50 def self.attribute_map { :'type' => :'type', :'codes' => :'codes', :'expiration_datetime' => :'expiration_datetime' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/ifeelgoods/models/redemption_reward_codes.rb', line 167 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 82 |
# File 'lib/ifeelgoods/models/redemption_reward_codes.rb', line 78 def self.openapi_nullable Set.new([ :'expiration_datetime' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 |
# File 'lib/ifeelgoods/models/redemption_reward_codes.rb', line 69 def self.openapi_types { :'type' => :'String', :'codes' => :'Array<RedemptionRewardCodesCodesInner>', :'expiration_datetime' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
144 145 146 147 148 149 150 |
# File 'lib/ifeelgoods/models/redemption_reward_codes.rb', line 144 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && codes == o.codes && expiration_datetime == o.expiration_datetime end |
#eql?(o) ⇒ Boolean
154 155 156 |
# File 'lib/ifeelgoods/models/redemption_reward_codes.rb', line 154 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/ifeelgoods/models/redemption_reward_codes.rb', line 160 def hash [type, codes, expiration_datetime].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
117 118 119 120 121 |
# File 'lib/ifeelgoods/models/redemption_reward_codes.rb', line 117 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/ifeelgoods/models/redemption_reward_codes.rb', line 189 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
125 126 127 128 129 130 |
# File 'lib/ifeelgoods/models/redemption_reward_codes.rb', line 125 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' type_validator = EnumAttributeValidator.new('String', ["unique_code", "multiple_codes"]) return false unless type_validator.valid?(@type) true end |