Class: Ifeelgoods::VendorPlacesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/ifeelgoods/api/vendor_places_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ VendorPlacesApi

Returns a new instance of VendorPlacesApi.



19
20
21
# File 'lib/ifeelgoods/api/vendor_places_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/ifeelgoods/api/vendor_places_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#list_client_vendor_places(client_id, opts = {}) ⇒ ListClientVendorPlaces200Response

List all vendor places Use this function to list vendor places for a specific client. This endpoint is available only to clients subscribed to Vendor Places API access.

Parameters:

  • client_id (String)

    The client identifier

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :skus (Array<String>)

    Filter by a list of brand SKUs

  • :zip_code (String)
  • :page (Integer) — default: default to 1
  • :per_page (Integer) — default: default to 20

Returns:



31
32
33
34
# File 'lib/ifeelgoods/api/vendor_places_api.rb', line 31

def list_client_vendor_places(client_id, opts = {})
  data, _status_code, _headers = list_client_vendor_places_with_http_info(client_id, opts)
  data
end

#list_client_vendor_places_with_http_info(client_id, opts = {}) ⇒ Array<(ListClientVendorPlaces200Response, Integer, Hash)>

List all vendor places Use this function to list vendor places for a specific client. This endpoint is available only to clients subscribed to Vendor Places API access.

Parameters:

  • client_id (String)

    The client identifier

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :skus (Array<String>)

    Filter by a list of brand SKUs

  • :zip_code (String)
  • :page (Integer) — default: default to 1
  • :per_page (Integer) — default: default to 20

Returns:



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/ifeelgoods/api/vendor_places_api.rb', line 45

def list_client_vendor_places_with_http_info(client_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: VendorPlacesApi.list_client_vendor_places ...'
  end
  # verify the required parameter 'client_id' is set
  if @api_client.config.client_side_validation && client_id.nil?
    fail ArgumentError, "Missing the required parameter 'client_id' when calling VendorPlacesApi.list_client_vendor_places"
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling VendorPlacesApi.list_client_vendor_places, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] > 10000
    fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling VendorPlacesApi.list_client_vendor_places, must be smaller than or equal to 10000.'
  end

  if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling VendorPlacesApi.list_client_vendor_places, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/fulfillment/v2/clients/{client_id}/vendor_places'.sub('{client_id}', CGI.escape(client_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'skus'] = @api_client.build_collection_param(opts[:'skus'], :multi) if !opts[:'skus'].nil?
  query_params[:'zip_code'] = opts[:'zip_code'] if !opts[:'zip_code'].nil?
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListClientVendorPlaces200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['api_key', 'bearer_auth', 'api_secret']

  new_options = opts.merge(
    :operation => :"VendorPlacesApi.list_client_vendor_places",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VendorPlacesApi#list_client_vendor_places\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end