Class: Ifeelgoods::PromotionsApi
- Inherits:
-
Object
- Object
- Ifeelgoods::PromotionsApi
- Defined in:
- lib/ifeelgoods/api/promotions_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_promotion_by_id(promotion_id, opts = {}) ⇒ GetPromotionByID200Response
Get a promotion Use this function to retrieve detailed information about a promotion and the list of the rewards available for delivery as part of this operation.
-
#get_promotion_by_id_with_http_info(promotion_id, opts = {}) ⇒ Array<(GetPromotionByID200Response, Integer, Hash)>
Get a promotion Use this function to retrieve detailed information about a promotion and the list of the rewards available for delivery as part of this operation.
-
#initialize(api_client = ApiClient.default) ⇒ PromotionsApi
constructor
A new instance of PromotionsApi.
-
#list_client_promotions(client_id, opts = {}) ⇒ ListClientPromotions200Response
List all Promotions Use this function to list all the promotions of a specific client.
-
#list_client_promotions_with_http_info(client_id, opts = {}) ⇒ Array<(ListClientPromotions200Response, Integer, Hash)>
List all Promotions Use this function to list all the promotions of a specific client.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PromotionsApi
Returns a new instance of PromotionsApi.
19 20 21 |
# File 'lib/ifeelgoods/api/promotions_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ifeelgoods/api/promotions_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_promotion_by_id(promotion_id, opts = {}) ⇒ GetPromotionByID200Response
Get a promotion Use this function to retrieve detailed information about a promotion and the list of the rewards available for delivery as part of this operation
27 28 29 30 |
# File 'lib/ifeelgoods/api/promotions_api.rb', line 27 def get_promotion_by_id(promotion_id, opts = {}) data, _status_code, _headers = get_promotion_by_id_with_http_info(promotion_id, opts) data end |
#get_promotion_by_id_with_http_info(promotion_id, opts = {}) ⇒ Array<(GetPromotionByID200Response, Integer, Hash)>
Get a promotion Use this function to retrieve detailed information about a promotion and the list of the rewards available for delivery as part of this operation
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/ifeelgoods/api/promotions_api.rb', line 37 def get_promotion_by_id_with_http_info(promotion_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PromotionsApi.get_promotion_by_id ...' end # verify the required parameter 'promotion_id' is set if @api_client.config.client_side_validation && promotion_id.nil? fail ArgumentError, "Missing the required parameter 'promotion_id' when calling PromotionsApi.get_promotion_by_id" end # resource path local_var_path = '/fulfillment/v2/promotions/{promotion_id}'.sub('{promotion_id}', CGI.escape(promotion_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetPromotionByID200Response' # auth_names auth_names = opts[:debug_auth_names] || ['api_key', 'bearer_auth', 'api_secret'] = opts.merge( :operation => :"PromotionsApi.get_promotion_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PromotionsApi#get_promotion_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_client_promotions(client_id, opts = {}) ⇒ ListClientPromotions200Response
List all Promotions Use this function to list all the promotions of a specific client
92 93 94 95 |
# File 'lib/ifeelgoods/api/promotions_api.rb', line 92 def list_client_promotions(client_id, opts = {}) data, _status_code, _headers = list_client_promotions_with_http_info(client_id, opts) data end |
#list_client_promotions_with_http_info(client_id, opts = {}) ⇒ Array<(ListClientPromotions200Response, Integer, Hash)>
List all Promotions Use this function to list all the promotions of a specific client
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/ifeelgoods/api/promotions_api.rb', line 104 def list_client_promotions_with_http_info(client_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PromotionsApi.list_client_promotions ...' end # verify the required parameter 'client_id' is set if @api_client.config.client_side_validation && client_id.nil? fail ArgumentError, "Missing the required parameter 'client_id' when calling PromotionsApi.list_client_promotions" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling PromotionsApi.list_client_promotions, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] > 10000 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling PromotionsApi.list_client_promotions, must be smaller than or equal to 10000.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] < 1 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling PromotionsApi.list_client_promotions, must be greater than or equal to 1.' end # resource path local_var_path = '/fulfillment/v2/clients/{client_id}/promotions'.sub('{client_id}', CGI.escape(client_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListClientPromotions200Response' # auth_names auth_names = opts[:debug_auth_names] || ['api_key', 'bearer_auth', 'api_secret'] = opts.merge( :operation => :"PromotionsApi.list_client_promotions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PromotionsApi#list_client_promotions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |