Class: Ifeelgoods::RedemptionReward
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Ifeelgoods::RedemptionReward
- Defined in:
- lib/ifeelgoods/models/redemption_reward.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#name ⇒ Object
Uggy Gift Card 10€.
-
#sku ⇒ Object
Unique identifier that represents the reward (eg.
APP-ITC-10USD-US). -
#state ⇒ Object
Current availability outcome of the offer based on its setup and availability checks.
-
#status ⇒ Object
Current lifecycle status of the offer (enabled, paused, disabled).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RedemptionReward
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RedemptionReward
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Ifeelgoods::RedemptionReward` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Ifeelgoods::RedemptionReward`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'sku') self.sku = attributes[:'sku'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'state') self.state = attributes[:'state'] end end |
Instance Attribute Details
#name ⇒ Object
Uggy Gift Card 10€
19 20 21 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 19 def name @name end |
#sku ⇒ Object
Unique identifier that represents the reward (eg. APP-ITC-10USD-US). It must be used with the redeem APIs.
22 23 24 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 22 def sku @sku end |
#state ⇒ Object
Current availability outcome of the offer based on its setup and availability checks. This field explains why an offer can or cannot be used at the moment.
28 29 30 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 28 def state @state end |
#status ⇒ Object
Current lifecycle status of the offer (enabled, paused, disabled). Use this field to understand whether the offer is currently intended to be active for your program.
25 26 27 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 25 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 53 def self.attribute_map { :'name' => :'name', :'sku' => :'sku', :'status' => :'status', :'state' => :'state' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 186 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 83 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 73 def self.openapi_types { :'name' => :'String', :'sku' => :'String', :'status' => :'String', :'state' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
162 163 164 165 166 167 168 169 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 162 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && sku == o.sku && status == o.status && state == o.state end |
#eql?(o) ⇒ Boolean
173 174 175 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 173 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
179 180 181 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 179 def hash [name, sku, status, state].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
123 124 125 126 127 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 123 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 208 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
131 132 133 134 135 136 137 138 |
# File 'lib/ifeelgoods/models/redemption_reward.rb', line 131 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["disabled", "enabled", "paused"]) return false unless status_validator.valid?(@status) state_validator = EnumAttributeValidator.new('String', ["invalid_reward", "temporarily_unavailable", "invalid_reward_for_redemption_flow", "no_allocation", "ready"]) return false unless state_validator.valid?(@state) true end |