Class: Ifeelgoods::RewardsApi
- Inherits:
-
Object
- Object
- Ifeelgoods::RewardsApi
- Defined in:
- lib/ifeelgoods/api/rewards_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_reward_by_sku(sku, opts = {}) ⇒ GetRewardBySKU200Response
Get a Reward Use this function to retrieve detailed description about a reward.
-
#get_reward_by_sku_with_http_info(sku, opts = {}) ⇒ Array<(GetRewardBySKU200Response, Integer, Hash)>
Get a Reward Use this function to retrieve detailed description about a reward.
-
#initialize(api_client = ApiClient.default) ⇒ RewardsApi
constructor
A new instance of RewardsApi.
-
#list_rewards(opts = {}) ⇒ ListRewards200Response
List all Rewards Use this function to list all the rewards from the Ifeelgoods Catalog.
-
#list_rewards_with_http_info(opts = {}) ⇒ Array<(ListRewards200Response, Integer, Hash)>
List all Rewards Use this function to list all the rewards from the Ifeelgoods Catalog.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ RewardsApi
Returns a new instance of RewardsApi.
19 20 21 |
# File 'lib/ifeelgoods/api/rewards_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ifeelgoods/api/rewards_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_reward_by_sku(sku, opts = {}) ⇒ GetRewardBySKU200Response
Get a Reward Use this function to retrieve detailed description about a reward
27 28 29 30 |
# File 'lib/ifeelgoods/api/rewards_api.rb', line 27 def get_reward_by_sku(sku, opts = {}) data, _status_code, _headers = get_reward_by_sku_with_http_info(sku, opts) data end |
#get_reward_by_sku_with_http_info(sku, opts = {}) ⇒ Array<(GetRewardBySKU200Response, Integer, Hash)>
Get a Reward Use this function to retrieve detailed description about a reward
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/ifeelgoods/api/rewards_api.rb', line 37 def get_reward_by_sku_with_http_info(sku, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RewardsApi.get_reward_by_sku ...' end # verify the required parameter 'sku' is set if @api_client.config.client_side_validation && sku.nil? fail ArgumentError, "Missing the required parameter 'sku' when calling RewardsApi.get_reward_by_sku" end # resource path local_var_path = '/fulfillment/v2/rewards/{sku}'.sub('{sku}', CGI.escape(sku.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetRewardBySKU200Response' # auth_names auth_names = opts[:debug_auth_names] || ['api_key', 'bearer_auth', 'api_secret'] = opts.merge( :operation => :"RewardsApi.get_reward_by_sku", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RewardsApi#get_reward_by_sku\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_rewards(opts = {}) ⇒ ListRewards200Response
List all Rewards Use this function to list all the rewards from the Ifeelgoods Catalog
93 94 95 96 |
# File 'lib/ifeelgoods/api/rewards_api.rb', line 93 def list_rewards(opts = {}) data, _status_code, _headers = list_rewards_with_http_info(opts) data end |
#list_rewards_with_http_info(opts = {}) ⇒ Array<(ListRewards200Response, Integer, Hash)>
List all Rewards Use this function to list all the rewards from the Ifeelgoods Catalog
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/ifeelgoods/api/rewards_api.rb', line 106 def list_rewards_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RewardsApi.list_rewards ...' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling RewardsApi.list_rewards, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] > 10000 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling RewardsApi.list_rewards, must be smaller than or equal to 10000.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] < 1 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling RewardsApi.list_rewards, must be greater than or equal to 1.' end # resource path local_var_path = '/fulfillment/v2/rewards' # query parameters query_params = opts[:query_params] || {} query_params[:'sku'] = opts[:'sku'] if !opts[:'sku'].nil? query_params[:'client_id'] = opts[:'client_id'] if !opts[:'client_id'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListRewards200Response' # auth_names auth_names = opts[:debug_auth_names] || ['api_key', 'bearer_auth', 'api_secret'] = opts.merge( :operation => :"RewardsApi.list_rewards", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RewardsApi#list_rewards\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |